@@ -17,8 +17,10 @@ from typing import Dict, List, Mapping, Sequence
 
 from .literals import (
     AddressTypeType,
+    AssetStateType,
     CatalogItemClassType,
     CatalogItemStatusType,
+    ComputeAssetStateType,
     FiberOpticCableTypeType,
     LineItemStatusType,
     MaximumSupportedWeightLbsType,
@@ -26,10 +28,12 @@ from .literals import (
     OrderStatusType,
     OrderTypeType,
     PaymentOptionType,
+    PaymentTermType,
     PowerConnectorType,
     PowerDrawKvaType,
     PowerFeedDropType,
     PowerPhaseType,
+    ShipmentCarrierType,
     SupportedHardwareTypeType,
     SupportedStorageEnumType,
     UplinkCountType,
@@ -68,7 +72,8 @@ __all__ = (
     "InstanceTypeItemTypeDef",
     "GetSiteAddressInputRequestTypeDef",
     "GetSiteInputRequestTypeDef",
-    "LineItemTypeDef",
+    "LineItemAssetInformationTypeDef",
+    "ShipmentInformationTypeDef",
     "ListAssetsInputRequestTypeDef",
     "ListCatalogItemsInputRequestTypeDef",
     "ListOrdersInputRequestTypeDef",
@@ -98,7 +103,7 @@ __all__ = (
     "CreateSiteInputRequestTypeDef",
     "SiteTypeDef",
     "GetOutpostInstanceTypesOutputTypeDef",
-    "OrderTypeDef",
+    "LineItemTypeDef",
     "ListOrdersOutputTypeDef",
     "ListAssetsOutputTypeDef",
     "GetCatalogItemOutputTypeDef",
@@ -108,6 +113,7 @@ __all__ = (
     "ListSitesOutputTypeDef",
     "UpdateSiteOutputTypeDef",
     "UpdateSiteRackPhysicalPropertiesOutputTypeDef",
+    "OrderTypeDef",
     "CreateOrderOutputTypeDef",
     "GetOrderOutputTypeDef",
 )
@@ -152,6 +158,7 @@ ComputeAttributesTypeDef = TypedDict(
     "ComputeAttributesTypeDef",
     {
         "HostId": str,
+        "State": ComputeAssetStateType,
     },
     total=False,
 )
@@ -355,13 +362,20 @@ GetSiteInputRequestTypeDef = TypedDict(
     },
 )
 
-LineItemTypeDef = TypedDict(
-    "LineItemTypeDef",
+LineItemAssetInformationTypeDef = TypedDict(
+    "LineItemAssetInformationTypeDef",
     {
-        "CatalogItemId": str,
-        "LineItemId": str,
-        "Quantity": int,
-        "Status": LineItemStatusType,
+        "AssetId": str,
+        "MacAddressList": List[str],
+    },
+    total=False,
+)
+
+ShipmentInformationTypeDef = TypedDict(
+    "ShipmentInformationTypeDef",
+    {
+        "ShipmentTrackingNumber": str,
+        "ShipmentCarrier": ShipmentCarrierType,
     },
     total=False,
 )
@@ -378,6 +392,7 @@ _OptionalListAssetsInputRequestTypeDef = TypedDict(
         "HostIdFilter": Sequence[str],
         "MaxResults": int,
         "NextToken": str,
+        "StatusFilter": Sequence[AssetStateType],
     },
     total=False,
 )
@@ -604,7 +619,7 @@ _RequiredCreateOrderInputRequestTypeDef = TypedDict(
 _OptionalCreateOrderInputRequestTypeDef = TypedDict(
     "_OptionalCreateOrderInputRequestTypeDef",
     {
-        "PaymentTerm": Literal["THREE_YEARS"],
+        "PaymentTerm": PaymentTermType,
     },
     total=False,
 )
@@ -749,16 +764,15 @@ GetOutpostInstanceTypesOutputTypeDef = TypedDict(
     },
 )
 
-OrderTypeDef = TypedDict(
-    "OrderTypeDef",
+LineItemTypeDef = TypedDict(
+    "LineItemTypeDef",
     {
-        "OutpostId": str,
-        "OrderId": str,
-        "Status": OrderStatusType,
-        "LineItems": List[LineItemTypeDef],
-        "PaymentOption": PaymentOptionType,
-        "OrderSubmissionDate": datetime,
-        "OrderFulfilledDate": datetime,
+        "CatalogItemId": str,
+        "LineItemId": str,
+        "Quantity": int,
+        "Status": LineItemStatusType,
+        "ShipmentInformation": ShipmentInformationTypeDef,
+        "AssetInformationList": List[LineItemAssetInformationTypeDef],
     },
     total=False,
 )
@@ -839,6 +853,20 @@ UpdateSiteRackPhysicalPropertiesOutputTypeDef = TypedDict(
     },
 )
 
+OrderTypeDef = TypedDict(
+    "OrderTypeDef",
+    {
+        "OutpostId": str,
+        "OrderId": str,
+        "Status": OrderStatusType,
+        "LineItems": List[LineItemTypeDef],
+        "PaymentOption": PaymentOptionType,
+        "OrderSubmissionDate": datetime,
+        "OrderFulfilledDate": datetime,
+    },
+    total=False,
+)
+
 CreateOrderOutputTypeDef = TypedDict(
     "CreateOrderOutputTypeDef",
     {
